This issue tracker is for reporting bugs in cwltool (the CWL reference implementation) itself. Please use the [Gitter channel](https://gitter.im/common-workflow-language/common-workflow-language) or [CWL Discourse Forum](https://cwl.discourse.group/) for general questions about using cwltool to create/run workflows or issues not related to cwltool. Don't forget to use cwl tag when posting on Biostars Forum.

If you'd like to report a bug, fill out the template below and provide any extra information that may be useful / related to your problem. Ideally, you create an [a Minimal, Complete, and Verifiable example](http://stackoverflow.com/help/mcve) reproducing the problem before opening an issue to ensure it's not caused by something in your code.

Before you submit, please delete this help text above the ---
Thanks!
---

## Expected Behavior
Tell us what should happen

## Actual Behavior
Tell us what happens instead

## Workflow Code
```
Paste the template code (ideally a minimal example) that causes the issue

```

## Full Traceback
```pytb
Paste the full traceback in case there is an exception
Run the workflow with ``--debug`` flag for more verbose logging 
```

## Your Environment
* cwltool version: 
Check using ``cwltool --version``
